==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/list-view/ListView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/list-view/ListView.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/data-provider', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../hooks/useQuery.es', '../../utils/client.es', '../management-toolbar/index.es', '../management-toolbar/search/SearchContext.es', '../management-toolbar/search/SearchSubnavigationBar.es', '../table/TableWithPagination.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dataProvider = require("@frontend-taglib-clay$clayui/data-provider");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _useQuery3 = _interopRequireDefault(require("../../hooks/useQuery.es"));

  var _client = require("../../utils/client.es");

  var _index = require("../management-toolbar/index.es");

  var _SearchContext = _interopRequireWildcard(require("../management-toolbar/search/SearchContext.es"));

  var _SearchSubnavigationBar = _interopRequireDefault(require("../management-toolbar/search/SearchSubnavigationBar.es"));

  var _TableWithPagination = _interopRequireDefault(require("../table/TableWithPagination.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var actions = _ref.actions,
        addButton = _ref.addButton,
        children = _ref.children,
        columns = _ref.columns,
        emptyState = _ref.emptyState,
        endpoint = _ref.endpoint,
        history = _ref.history,
        queryParams = _ref.queryParams;

    var _useQuery = (0, _useQuery3["default"])(history, _objectSpread({
      keywords: '',
      page: 1,
      pageSize: 20,
      sort: ''
    }, queryParams)),
        _useQuery2 = _slicedToArray(_useQuery, 2),
        query = _useQuery2[0],
        setQuery = _useQuery2[1];

    var dispatch = function dispatch(action) {
      return setQuery((0, _SearchContext.reducer)(query, action));
    };

    var _useResource = (0, _dataProvider.useResource)({
      fetchDelay: 0,
      fetchOptions: {
        credentials: 'same-origin',
        method: 'GET'
      },
      link: (0, _client.getURL)(endpoint),
      onNetworkStatusChange: function onNetworkStatusChange(status) {
        return setLoading(status < 4);
      },
      variables: _objectSpread({}, query)
    }),
        refetch = _useResource.refetch,
        resource = _useResource.resource;

    var items = [];
    var totalCount = 0;
    var totalPages = 1;

    if (resource) {
      var _resource$items = resource.items;
      items = _resource$items === void 0 ? [] : _resource$items;
      totalCount = resource.totalCount;
      totalPages = resource.lastPage;

      if (query.page > totalPages) {
        dispatch({
          page: totalPages,
          type: 'CHANGE_PAGE'
        });
      }
    }

    var refetchOnActions;

    if (actions && actions.length > 0) {
      refetchOnActions = actions.map(function (_action) {
        if (!_action.action) {
          return _action;
        }

        return _objectSpread({}, _action, {
          action: function action(item) {
            _action.action(item).then(function (isRefetch) {
              if (!isRefetch) {
                return;
              }

              refetch();
            });
          }
        });
      });
    }

    var _useState = (0, _react.useState)(true),
        _useState2 = _slicedToArray(_useState, 2),
        isLoading = _useState2[0],
        setLoading = _useState2[1];

    return _react["default"].createElement(_SearchContext["default"].Provider, {
      value: [query, dispatch]
    }, _react["default"].createElement(_index.ManagementToolbar, null, _react["default"].createElement(_index.SearchBar, {
      columns: columns,
      totalCount: totalCount
    }), addButton && addButton()), _react["default"].createElement(_SearchSubnavigationBar["default"], {
      isLoading: isLoading,
      totalCount: totalCount
    }), _react["default"].createElement(_TableWithPagination["default"], {
      actions: refetchOnActions,
      columns: columns,
      emptyState: emptyState,
      isEmpty: totalCount === 0,
      isLoading: isLoading,
      items: items.map(function (item, index) {
        return children(item, index);
      }),
      keywords: query.keywords,
      totalCount: totalCount
    }));
  });

  exports["default"] = _default;
  //# sourceMappingURL=ListView.es.js.map
});
//# sourceMappingURL=ListView.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/list-view/ListView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/list-view/ListView.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/data-provider', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../hooks/useQuery.es', '../../utils/client.es', '../management-toolbar/index.es', '../management-toolbar/search/SearchContext.es', '../management-toolbar/search/SearchSubnavigationBar.es', '../table/TableWithPagination.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dataProvider = require("@frontend-taglib-clay$clayui/data-provider");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _useQuery3 = _interopRequireDefault(require("../../hooks/useQuery.es"));

  var _client = require("../../utils/client.es");

  var _index = require("../management-toolbar/index.es");

  var _SearchContext = _interopRequireWildcard(require("../management-toolbar/search/SearchContext.es"));

  var _SearchSubnavigationBar = _interopRequireDefault(require("../management-toolbar/search/SearchSubnavigationBar.es"));

  var _TableWithPagination = _interopRequireDefault(require("../table/TableWithPagination.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var actions = _ref.actions,
        addButton = _ref.addButton,
        children = _ref.children,
        columns = _ref.columns,
        emptyState = _ref.emptyState,
        endpoint = _ref.endpoint,
        history = _ref.history,
        queryParams = _ref.queryParams;

    var _useQuery = (0, _useQuery3["default"])(history, _objectSpread({
      keywords: '',
      page: 1,
      pageSize: 20,
      sort: ''
    }, queryParams)),
        _useQuery2 = _slicedToArray(_useQuery, 2),
        query = _useQuery2[0],
        setQuery = _useQuery2[1];

    var dispatch = (0, _react.useCallback)(function (action) {
      return setQuery((0, _SearchContext.reducer)(query, action));
    }, [query, setQuery]);

    var _useResource = (0, _dataProvider.useResource)({
      fetchDelay: 0,
      fetchOptions: {
        credentials: 'same-origin',
        method: 'GET'
      },
      link: (0, _client.getURL)(endpoint),
      onNetworkStatusChange: function onNetworkStatusChange(status) {
        return setLoading(status < 4);
      },
      variables: _objectSpread({}, query)
    }),
        refetch = _useResource.refetch,
        resource = _useResource.resource;

    var items = [];
    var totalCount = 0;
    var totalPages = 1;

    if (resource) {
      var _resource$items = resource.items;
      items = _resource$items === void 0 ? [] : _resource$items;
      totalCount = resource.totalCount;
      totalPages = resource.lastPage;
    }

    (0, _react.useEffect)(function () {
      if (query.page > totalPages) {
        dispatch({
          page: totalPages,
          type: 'CHANGE_PAGE'
        });
      }
    }, [dispatch, query.page, totalPages]);
    var refetchOnActions;

    if (actions && actions.length > 0) {
      refetchOnActions = actions.map(function (_action) {
        if (!_action.action) {
          return _action;
        }

        return _objectSpread({}, _action, {
          action: function action(item) {
            _action.action(item).then(function (isRefetch) {
              if (!isRefetch) {
                return;
              }

              refetch();
            });
          }
        });
      });
    }

    var _useState = (0, _react.useState)(true),
        _useState2 = _slicedToArray(_useState, 2),
        isLoading = _useState2[0],
        setLoading = _useState2[1];

    return _react["default"].createElement(_SearchContext["default"].Provider, {
      value: [query, dispatch]
    }, _react["default"].createElement(_index.ManagementToolbar, null, _react["default"].createElement(_index.SearchBar, {
      columns: columns,
      totalCount: totalCount
    }), addButton && addButton()), _react["default"].createElement(_SearchSubnavigationBar["default"], {
      isLoading: isLoading,
      totalCount: totalCount
    }), _react["default"].createElement(_TableWithPagination["default"], {
      actions: refetchOnActions,
      columns: columns,
      emptyState: emptyState,
      isEmpty: totalCount === 0,
      isLoading: isLoading,
      items: items.map(function (item, index) {
        return children(item, index);
      }),
      keywords: query.keywords,
      totalCount: totalCount
    }));
  });

  exports["default"] = _default;
  //# sourceMappingURL=ListView.es.js.map
});
//# sourceMappingURL=ListView.es.js.map
